@@ -9,12 +9,10 @@ context("combine smsm_set objects")
 #------------------------------------------------------------------------------
 
 test_that("expected errors and warnings are generated", {
-  load("C:/Github/synthACS/tests/testthat/par_sim_anneal.Rdata")
-  
   # create smsm_set object 
-  cll <- all_geogs_add_constraint(attr_name= "age", attr_total_list= a, macro_micro= syn)
-  cll <- all_geogs_add_constraint(attr_name= "gender", attr_total_list= g, macro_micro= syn, constraint_list_list= cll)
-  cll <- all_geogs_add_constraint(attr_name= "edu_attain", attr_total_list= e, macro_micro= syn, constraint_list_list= cll)
+  cll <- all_geogs_add_constraint(attr_name= "age", attr_total_list= a_par, macro_micro= syn)
+  cll <- all_geogs_add_constraint(attr_name= "gender", attr_total_list= g_par, macro_micro= syn, constraint_list_list= cll)
+  cll <- all_geogs_add_constraint(attr_name= "edu_attain", attr_total_list= e_par, macro_micro= syn, constraint_list_list= cll)
   
   opt_geog <- all_geog_optimize_microdata(syn, prob_name= "p", constraint_list_list= cll, seed= 100L,
                                           p_accept= 0.4,  max_iter= 2L, verbose= FALSE)
@@ -64,12 +62,10 @@ test_that("expected errors and warnings are generated", {
 })
 
 test_that("returns correctly", {
-  load("C:/Github/synthACS/tests/testthat/par_sim_anneal.Rdata")
-  
-  # create smsm_set object 
-  cll <- all_geogs_add_constraint(attr_name= "age", attr_total_list= a, macro_micro= syn)
-  cll <- all_geogs_add_constraint(attr_name= "gender", attr_total_list= g, macro_micro= syn, constraint_list_list= cll)
-  cll <- all_geogs_add_constraint(attr_name= "edu_attain", attr_total_list= e, macro_micro= syn, constraint_list_list= cll)
+ # create smsm_set object 
+  cll <- all_geogs_add_constraint(attr_name= "age", attr_total_list= a_par, macro_micro= syn)
+  cll <- all_geogs_add_constraint(attr_name= "gender", attr_total_list= g_par, macro_micro= syn, constraint_list_list= cll)
+  cll <- all_geogs_add_constraint(attr_name= "edu_attain", attr_total_list= e_par, macro_micro= syn, constraint_list_list= cll)
   
   opt_geog <- all_geog_optimize_microdata(syn, prob_name= "p", constraint_list_list= cll,
                                           max_iter= 2L, verbose= FALSE)
